@@ -27,11 +27,11 @@ Moonshine::Test - Test!
 
 =head1 VERSION
 
-Version 0.11
+Version 0.12
 
 =cut
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 =head1 SYNOPSIS
 
@@ -104,6 +104,8 @@ moon_test_one can currently run the following tests.
 
 =over
 
+=item ok - ok - a true value 
+
 =item ref - is_deeply - expected [] or {}
 
 =item scalar - is - expected '',
@@ -146,6 +148,8 @@ moon_test_one can currently run the following tests.
 
 =item list_index_like - like - ''
 
+=item skip - ok(1)
+
 =back
 
 =head3 catch
@@ -408,6 +412,12 @@ sub moon_test_one {
                 expected => $expected[0],
             );
         }
+        when ('ok') {
+            return ok(@test, "$test_name is ok");
+        }
+        when ('skip') {
+            return ok(1, "$test_name - skip");
+        }
         default {
             ok(0);
             diag "Unknown instruction{test}: $_ passed to moon_test_one";
